@@ -130,6 +130,8 @@ class Job(object):
     SUCCESS_RESULT = 'success'
     ABORTED_RESULT = 'aborted'
 
+    TIME_NULL = -1
+
     @staticmethod
     def create(scheduler, executable, job_doc):
         job = Job(scheduler, executable, job_doc)
@@ -207,8 +209,9 @@ class Job(object):
     @staticmethod
     def save_action_to_file(action, f):
         parser = configparser.ConfigParser()
+        parser.add_section('action')
         for action_k, action_v in action.items():
-            parser.set('DEFAULT', action_k, action_v)
+            parser.set('action', action_k, action_v)
         parser.write(f)
         f.seek(0)
 
@@ -232,8 +235,14 @@ class Job(object):
     def schedule_cron_fields(self):
         cron_fields = ['year', 'month', 'day', 'week', 'day_of_week',
                        'hour', 'minute', 'second']
+        cron_schedule = {}
+        for cron in self.job_doc['job_schedule'].keys():
+            if cron.startswith('schedule_'):
+                cron_key = cron.split('_', 1)[1]
+                cron_schedule.update({
+                    cron_key: self.job_doc['job_schedule'][cron]})
         return {key: value
-                for key, value in self.job_doc['job_schedule'].items()
+                for key, value in cron_schedule.items()
                 if key in cron_fields}
 
     @property
@@ -268,6 +277,7 @@ class Job(object):
                 kwargs_date.update({
                     'end_date': end_date
                 })
+
         if self.schedule_date:
             return {'trigger': 'date',
                     'run_date': self.schedule_date}
@@ -280,15 +290,17 @@ class Job(object):
                 val, unit = self.schedule_interval.split(' ')
                 kwargs.update({unit: int(val)})
             return kwargs
-        else:
+        elif self.schedule_cron_fields:
+            kwargs = {'trigger': 'cron'}
+            kwargs.update(kwargs_date)
             cron_fields = self.schedule_cron_fields
-            if cron_fields:
-                kwargs = {'trigger': 'cron'}.update(kwargs_date)
-                return kwargs.update(cron_fields)
-        # no scheduling information, schedule to start within a few seconds
-        return {'trigger': 'date',
-                'run_date': datetime.datetime.now() +
-                datetime.timedelta(0, 2, 0)}
+            kwargs.update(cron_fields)
+            return kwargs
+        else:
+            # no scheduling information, schedule to start within a few seconds
+            return {'trigger': 'date',
+                    'run_date': datetime.datetime.now() +
+                    datetime.timedelta(0, 2, 0)}
 
     def process_event(self, job_doc):
         with self.scheduler.lock:
@@ -329,7 +341,7 @@ class Job(object):
             with tempfile.NamedTemporaryFile(delete=False) as config_file:
                 self.save_action_to_file(freezer_action, config_file)
                 config_file_name = config_file.name
-                freezer_command = '{0} --metadata-out - --config-file {1}'.\
+                freezer_command = '{0} --metadata-out - --config {1}'.\
                     format(self.executable, config_file.name)
                 self.process = subprocess.Popen(freezer_command.split(),
                                                 stdout=subprocess.PIPE,
@@ -393,14 +405,31 @@ class Job(object):
                 return True
         return False
 
+    def update_job_schedule_doc(self, **kwargs):
+        """
+        Updates the job_schedule section of the job doc with the
+        provided keyword args. No checks about accepted key/values
+        are being made here since they may vary in the future.
+
+        :param kwargs: keyword args to add
+        :return: None
+        """
+        job_schedule = self.job_doc['job_schedule']
+        job_schedule.update(kwargs)
+
     def execute(self):
         result = Job.SUCCESS_RESULT
         with self.scheduler.execution_lock:
             with self.scheduler.lock:
                 LOG.info('job {0} running'.format(self.id))
                 self.state = RunningState
-                self.job_doc_status = Job.RUNNING_STATUS
-                self.scheduler.update_job_status(self.id, self.job_doc_status)
+                self.update_job_schedule_doc(status=Job.RUNNING_STATUS,
+                                             result="",
+                                             time_started=int(time.time()),
+                                             time_ended=Job.TIME_NULL)
+                self.scheduler.update_job_schedule(
+                    self.id,
+                    self.job_doc['job_schedule'])
 
             self.start_session()
             # if the job contains exec action and the scheduler passes the
@@ -432,6 +461,7 @@ class Job(object):
             self.finish()
 
     def finish(self):
+        self.update_job_schedule_doc(time_ended=int(time.time()))
         self.end_session(self.result)
         with self.scheduler.lock:
             if self.event == Job.REMOVE_EVENT:
@@ -452,7 +482,9 @@ class Job(object):
             else:
                 self.job_doc_status = Job.SCHEDULED_STATUS
                 self.state = ScheduledState
-                self.scheduler.update_job_status(self.id, self.job_doc_status)
+                self.scheduler.update_job_schedule(
+                    self.id,
+                    self.job_doc['job_schedule'])
 
     def start_session(self):
         if not self.session_id:
