@@ -19,7 +19,7 @@ import win32event
 import win32service
 import win32serviceutil
 
-from freezer.winutils import set_environment
+from freezer.utils import winutils
 
 
 class PySvc(win32serviceutil.ServiceFramework):
@@ -32,7 +32,7 @@ class PySvc(win32serviceutil.ServiceFramework):
         # create an event to listen for stop requests on
         self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)
         self.home = r'C:\.freezer'
-        self.verify = True
+        self.insecure = False
 
     def SvcDoRun(self):
         """Run the windows service and start the scheduler in the background
@@ -57,18 +57,18 @@ class PySvc(win32serviceutil.ServiceFramework):
         win32event.SetEvent(self.hWaitStop)
 
     def main(self):
-        import freezer.apiclient.client
         from freezer.scheduler.freezer_scheduler import FreezerScheduler
+        from freezerclient.v1.client import Client
 
         servicemanager.LogMsg(
             servicemanager.EVENTLOG_INFORMATION_TYPE,
             servicemanager.PYS_SERVICE_STARTED,
             (self._svc_name_, ''))
 
-        set_environment(self.home)
+        winutils.set_environment(self.home)
 
         if os.environ.get('SERVICE_INSECURE'):
-            self.verify = False
+            self.insecure = True
 
         # Add support for keystone v2 and v3
         credentials = {}
@@ -80,7 +80,7 @@ class PySvc(win32serviceutil.ServiceFramework):
                 'auth_url': os.environ['OS_AUTH_URL'],
                 'endpoint': os.environ['OS_BACKUP_URL'],
                 'tenant_name': os.environ['OS_TENANT_NAME'],
-                'verify': self.verify
+                'insecure': self.insecure
             }
         elif os.environ['OS_IDENTITY_API_VERSION'] == 3:
             credentials = {
@@ -92,10 +92,10 @@ class PySvc(win32serviceutil.ServiceFramework):
                 'project_name': os.environ['OS_PROJECT_NAME'],
                 'user_domain_name': os.environ['OS_USER_DOMAIN_NAME'],
                 'project_domain_name': os.environ['OS_PROJECT_DOMAIN_NAME'],
-                'verify': self.verify
+                'insecure': self.insecure
             }
 
-        client = freezer.apiclient.client.Client(**credentials)
+        client = Client(**credentials)
 
         scheduler = FreezerScheduler(
             apiclient=client, interval=int(os.environ['SERVICE_INTERVAL']),
